@@ -1,4 +1,5 @@
 #List of useful pandas dataframe commands
+from contextlib import suppress
 import pandas as pd
 from openpyxl import load_workbook
 import glob
@@ -11,6 +12,7 @@ import pytesseract
 from PIL import Image
 import pytz
 import time
+from dateutil.relativedelta import relativedelta
 
 
 def df_retainCols(dfdata, collist): #deletes columns in df which are not there in list of columns
@@ -594,23 +596,55 @@ def number_converter(str_num: str) -> int:
         return [False]
 
 class TimeKeeper():
-    def __init__(self) -> None:
+    def __init__(self, supress:str) -> datetime:
+        '''
+        pass y flag to supresses printing by this class so that user can print as per his needs
+        '''
         self.start_time = datetime.datetime.now()
-        print(f'Started at: {self.start_time}')
+        print(f'\nStarted at: {self.start_time}')
         self.logs = []
+        self.logs.append(self.start_time)
+        self.supress = supress
+
+        return self.start_time
     
-    def log(self):
+    def log(self) -> datetime:
+        '''
+        returns difference as relativedelta value of difference between last log and 2nd last log entry
+        '''
         self.logs.append(datetime.datetime.now())
-        print(f'Runtime (sec): {self.logs[-1] - self.start_time}')
-        return self.logs[-1]
+        diff = relativedelta(self.logs[-1], self.logs[-2])
+        if self.supress == 'y':
+            pass
+        else:
+            print(f'\nLap runtime (sec): {diff}')
+            print(f'Total runtime (sec): {self.logs[-1] - self.start_time}')
+        
+        return diff
 
-    def get_log(self, log_idx):
-        print(f'Log runtime (sec): {self.logs[log_idx] - self.start_time}')
+    def get_log(self, log_idx:int) -> datetime:
+        '''
+        returns difference as relativedelta value of difference between given log and start time
+        '''
+        diff = relativedelta(self.logs[log_idx], self.start_time)
+        if self.supress == 'y':
+            pass
+        else:
+            print(f'\nRuntime since start (sec): {diff}')
+        
+        return diff
 
-    def end(self):
+    def end(self) -> datetime:
         self.end_time = datetime.datetime.now()
-        print(f'Total runtime (sec): {self.end_time - self.start_time}')
-        print(f'End time: {self.end_time}')
+        self.logs.append(self.end_time)
+        diff = relativedelta(self.end_time, self.start_time)
+        if self.supress == 'y':
+            pass
+        else:
+            print(f'\nTotal runtime (sec): {diff}')
+            print(f'End time: {self.end_time}')
+        
+        return diff
 
 def progress_bar(iteration, total, prefix = '', suffix = '', decimals = 1, length = 100, fill = '█', printEnd = '\r'):
     """
